@@ -4,7 +4,7 @@ package Dist::Zilla::MintingProfile::Author::ETHER;
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Mint distributions like ETHER does
 
-our $VERSION = '0.117';
+our $VERSION = '0.118';
 
 use Moose;
 with 'Dist::Zilla::Role::MintingProfile' => { -version => '5.047' };
@@ -17,7 +17,7 @@ sub profile_dir
 {
     my ($self, $profile_name) = @_;
 
-    die 'minting requires perl 5.014' unless $] >= 5.013002;
+    die 'minting requires perl 5.014' unless "$]" >= 5.013002;
 
     my $dist_name = 'Dist-Zilla-PluginBundle-Author-ETHER';
 
@@ -42,7 +42,7 @@ Dist::Zilla::MintingProfile::Author::ETHER - Mint distributions like ETHER does
 
 =head1 VERSION
 
-version 0.117
+version 0.118
 
 =head1 SYNOPSIS
 
