@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.116-5-g4b81f4d
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.117-7-g4cf3986
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.117';
+our $VERSION = '0.118';
 
 use Moose;
 with
@@ -168,7 +168,7 @@ sub configure
     # operations may be looking at the wrong directory! Take this into
     # consideration when running tests!
 
-    my $has_xs =()= glob('*.xs');
+    my $has_xs = glob('*.xs') ? 1 : 0;
     warn '[@Author::ETHER] XS-based distribution detected.', "\n" if $has_xs;
     die '[@Author::ETHER] no Makefile.PL found in the repository root: this is not very nice for contributors!', "\n"
         if $has_xs and not -e 'Makefile.PL';
@@ -256,8 +256,7 @@ sub configure
         [ 'Test::Kwalitee'      => { ':version' => '2.10', filename => 'xt/author/kwalitee.t' } ],
         [ 'MojibakeTests'       => { ':version' => '0.8' } ],
         [ 'Test::ReportPrereqs' => { ':version' => '0.022', verify_prereqs => 1, version_extractor => 'Module::Metadata',
-            exists $removed{PodCoverageTests} ? () : ( include => [ 'Pod::Coverage' ] ),
-          } ],
+            include => [ sort ( qw(autodie JSON::PP YAML), exists $removed{PodCoverageTests} ? () : 'Pod::Coverage' ) ] } ],
         [ 'Test::Portability'   => { ':version' => '2.000007' } ],
         [ 'Test::CleanNamespaces' => { ':version' => '0.006' } ],
 
@@ -473,7 +472,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.117
+version 0.118
 
 =head1 SYNOPSIS
 
@@ -603,7 +602,10 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     :version = 0.022
     verify_prereqs = 1
     version_extractor = Module::Metadata
+    include = JSON::PP
     include = Pod::Coverage
+    include = YAML
+    include = autodie
     [Test::Portability]
     :version = 2.000007
     [Test::CleanNamespaces]
@@ -683,7 +685,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
 
 
     ;;; Install Tool
-    <specified installer(s)>
+    ; <specified installer(s)>
 
     [Git::Contributors]
     :version = 0.004
